<?php
namespace Modules\Cadastros\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Util\SupUtilities;

class Sup10500AjustePrForneFiliService {

    public function __construct(SupUtilities $supUtilities) {
        $this->supUtilities = $supUtilities;
    }
    
    public function insertAjuste($row){
        try {
            $query = "INSERT INTO AJUSTEPRFORNFIL
                        (CDFORNECED, CDFILIAL, DTINIAJPRFORFIL, DTFINAJPRFORFIL, VRPERAJFORNFIL, IDCONSPERPIAJPR, NRORG)
                      VALUES
                        (:CDFORNECED, :CDFILIAL, :DTINIAJPRFORFIL, :DTFINAJPRFORFIL, :VRPERAJFORNFIL, :IDCONSPERPIAJPR, :NRORG)";
            $params = [
                'CDFILIAL'          => $row['CDFILIAL'],
                'CDFORNECED'        => $row['CDFORNECED'],
                'DTINIAJPRFORFIL'   => $row['DTINIAJPRFORFIL'],
                'DTFINAJPRFORFIL'   => $row['DTFINAJPRFORFIL'],
                'VRPERAJFORNFIL'    => floatval($row['VRPERAJFORNFIL']),
                'IDCONSPERPIAJPR'   => $row['IDCONSPERPIAJPR'],
                'NRORG'             => $row['NRORG']
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao inserir ajuste.');
        }
    }
    
    public function updateAjuste($row){
        try {
            $query = "UPDATE AJUSTEPRFORNFIL
                         SET DTFINAJPRFORFIL = :DTFINAJPRFORFIL, 
                             VRPERAJFORNFIL  = :VRPERAJFORNFIL, 
                             IDCONSPERPIAJPR = :IDCONSPERPIAJPR
                       WHERE CDFORNECED      = :P_CDFORNECED
                         AND CDFILIAL        = :P_CDFILIAL
                         AND DTINIAJPRFORFIL = :P_DTINIAJPRFORFIL
                         AND NRORG = :P_NRORG";
            $params = [
                'DTFINAJPRFORFIL'   => $row['DTFINAJPRFORFIL'],
                'VRPERAJFORNFIL'    => floatval($row['VRPERAJFORNFIL']),
                'IDCONSPERPIAJPR'   => $row['IDCONSPERPIAJPR'],
                'P_CDFILIAL'        => $row['CDFILIAL'],
                'P_CDFORNECED'      => $row['CDFORNECED'],
                'P_DTINIAJPRFORFIL' => $row['DTINIAJPRFORFIL'],
                'P_NRORG'           => $row['NRORG']
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao atualizar o ajuste.');
        }
    }
    
    public function deleteAjuste($data){
        try {
            $query = "DELETE FROM AJUSTEPRFORNFIL 
                       WHERE CDFORNECED      = :P_CDFORNECED
                         AND CDFILIAL        = :P_CDFILIAL
                         AND DTINIAJPRFORFIL = :P_DTINIAJPRFORFIL
                         AND NRORG = :P_NRORG";
            foreach($data as $row){
                $params = [
                    'P_CDFILIAL'        => $row['CDFILIAL'],
                    'P_CDFORNECED'      => $row['CDFORNECED'],
                    'P_DTINIAJPRFORFIL' => $row['DTINIAJPRFORFIL'],
                    'P_NRORG'           => $row['NRORG']
                ];
                $this->supUtilities->crud($query, $params);    
            }
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao excluir o ajuste.');
        }
    }
    
    public function updateCadAutomatico($row){
        try {
            $query = "UPDATE AJUSTEPRFORNFIL A
                         SET A.DTFINAJPRFORFIL = DECODE(:P_ATUAL_DT, 'S', :P_DTFIM, A.DTFINAJPRFORFIL),
                             A.VRPERAJFORNFIL  = :P_PERCENT, 
                             A.IDCONSPERPIAJPR = :P_PI_DSV
                       WHERE (INSTR(:P_CDFORNECED, A.CDFORNECED) > 0 OR (:P_CDFORNECED = 'T'))
                         AND (INSTR(:P_CDFILIAL, A.CDFILIAL) > 0     OR (:P_CDFILIAL   = 'T'))
                         AND A.DTINIAJPRFORFIL = :P_DTINI
                         AND A.NRORG = :P_NRORG";
            $params = [
                'P_ATUAL_DT'    => $row['atualizaData'],
                'P_DTFIM'       => $row['DTFINAJPRFORFIL'],
                'P_PERCENT'     => floatval($row['VRPERAJFORNFIL']),
                'P_PI_DSV'      => $row['IDCONSPERPIAJPR'],
                'P_CDFORNECED'  => $row['FORNECEDOR'],
                'P_CDFILIAL'    => $row['FILIAL'],
                'P_DTINI'       => $row['DTINIAJPRFORFIL'],
                'P_NRORG'       => $row['NRORG']
            ];
            $this->supUtilities->crud($query, $params);    
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao atualizar o ajuste.');
        }
    }
    
    public function insertCadAutomatico($row){
        try {
            $query = "INSERT INTO AJUSTEPRFORNFIL (CDFORNECED, CDFILIAL, DTINIAJPRFORFIL, DTFINAJPRFORFIL , VRPERAJFORNFIL, IDCONSPERPIAJPR, NRORG)
                      SELECT F.CDFORNECED, FI.CDFILIAL, :P_DTINI, :P_DTFIM, :P_PERCENT, :P_PI_DSV, :P_NRORG
                        FROM FORNECEDOR F, FILIAL FI
                       WHERE (INSTR(:P_CDFORNECED, F.CDFORNECED) > 0 OR (:P_CDFORNECED = 'T'))
                         AND (INSTR(:P_CDFILIAL, FI.CDFILIAL) > 0    OR (:P_CDFILIAL   = 'T'))
                         AND NOT EXISTS (SELECT 1 FROM AJUSTEPRFORNFIL A
                                          WHERE FI.CDFILIAL         = A.CDFILIAL
                                            AND A.CDFORNECED        = F.CDFORNECED
                                            AND A.DTINIAJPRFORFIL   = :P_DTINI
                                            AND A.NRORG             = :P_NRORG)";
            $params = [
                'P_DTINI'       => $row['DTINIAJPRFORFIL'],
                'P_DTFIM'       => $row['DTFINAJPRFORFIL'],
                'P_PERCENT'     => floatval($row['VRPERAJFORNFIL']),
                'P_PI_DSV'      => $row['IDCONSPERPIAJPR'],
                'P_CDFORNECED'  => $row['FORNECEDOR'],
                'P_CDFILIAL'    => $row['FILIAL'],
                'P_NRORG'       => $row['NRORG']
            ];
            $this->supUtilities->crud($query, $params);    
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao inserir ajuste.');
        }
    }
}