<?php

namespace Modules\OperadorLogistico\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Setforms2\Shared\ORM\DateTime;
use Setforms2\Shared\ORM\DateInterval;

class CalculoNecessidadeOLService {
    
    protected $connection;
    protected $newCode;
    
    public function __construct($entityManager, $environment, $newCode){
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
        $this->newCode = $newCode;
    }
    
    public function criaFiltroRelatInconsistencia($row){
        $filter = array(
		    array(
    		    "columnName" => "P_CDFILIOPELOG", 
    		    "value" => $row['CDFILIALOL'],
    		    "operator" => "="
		    ),
	        array(
    		    "columnName" => "P_CDPRODINI", 
    		    "value" => $row['CDPRODINI'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDPRODFIN", 
    		    "value" => $row['CDPRODFIN'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_DTINICIAL", 
    		    "value" => $row['DTINI'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_DTFINAL", 
    		    "value" => $row['DTFIM'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroCentral(){
        $filter = array(
		    array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $this->environment->getCdfilial(),
    		    "operator" => "="
		    ),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroParametros($row){
        $filter = array(
		    array(
    		    "columnName" => "CDFILIAL", 
    		    "value" => $row[0]['CENTRALCMP'],
    		    "operator" => "="
		    ),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function VERIFICA_CONS_OL($row){
        if ($row['CDSUBGRUPO'] == 'T'){
           $subgrupo = ''; 
        }
        $procedure = new StoredProcedure($this->connection, 'VERIFICA_CONS_OL');
        $procedure->addParam(new Param('P_CDFILIOPELOG', Param::PARAM_INPUT, $row['CDFILIALOL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $row['DTINI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $row['DTFIM'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODINI', Param::PARAM_INPUT, $row['CDPRODINI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODFIN', Param::PARAM_INPUT, $row['CDPRODFIN'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPPROD', Param::PARAM_INPUT, $row['CDGRUPPROD'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDSUBGRUPO', Param::PARAM_INPUT, $subgrupo, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPFILI', Param::PARAM_INPUT, $row['CDGRUPFILI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ROWSAFFECT', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 1));
        return $procedure->execute();
    }
    
    public function NovoCodigo($tabela){
        return $this->newCode->getCodeByTableName($tabela, $this->environment->getNrorg());
    }
    
    public function NECESSIDADE_OL($row) {
        $codigo = $this->NovoCodigo('CONSSOLCMPOL');
        
        $cdsubgrupo = $row['CDSUBGRUPO'];
        if ($cdsubgrupo == 'T'){
           $cdsubgrupo = ''; 
        }
        $cdgrupprod = $row['CDGRUPPROD'];
        if($cdsubgrupo == ''){
            if($cdgrupprod !== ''){
                $cdgrupprod = '';
            }
        }
        
        $procedure = new StoredProcedure($this->connection, 'NECESSIDADE_OL');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $row['CDFILIALOL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $row['DTINI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $row['DTFIM'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODINI', Param::PARAM_INPUT, $row['CDPRODINI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODFIN', Param::PARAM_INPUT, $row['CDPRODFIN'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PEACRESCIMO', Param::PARAM_INPUT, $row['PEACRESCIMO'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $this->environment->getCdoperador(), Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQCONSOL', Param::PARAM_INPUT, $codigo, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, $this->environment->getCdfilial(), Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PRIORIZAREST', Param::PARAM_INPUT, $row['embDispEstoqueOL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PREVISAOCONSUMO', Param::PARAM_INPUT, $row['consPrevisaoConsumo'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_GERASOLOPERLOG', Param::PARAM_INPUT, $row['geraSolicitacaOL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDSUBGRUPO', Param::PARAM_INPUT, $cdsubgrupo, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPPROD', Param::PARAM_INPUT, $cdgrupprod, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPFILI', Param::PARAM_INPUT, $row['CDGRUPFILI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ROWSAFFECT', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 1));
        $resposta = $procedure->execute();
        return $codigo.$resposta['P_ROWSAFFECT'];
    }
    
    public function criaFiltroVdNeceCompra($row){
        $filter = array(
		    array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $row['CDFILIALOL'],
    		    "operator" => "="
		    ),
		     array(
    		    "columnName" => "P_CDPRODINICAL", 
    		    "value" => $row['CDPRODINI'],
    		    "operator" => "="
		    ),
		     array(
    		    "columnName" => "P_CDPRODFINAL", 
    		    "value" => $row['PRODUTOFIN'],
    		    "operator" => "="
		    ),
		     array(
    		    "columnName" => "P_DTINICIAL", 
    		    "value" => $row['DTINI'],
    		    "operator" => "="
		    ),
		     array(
    		    "columnName" => "P_DTFINAL", 
    		    "value" => $row['DTFIM'],
    		    "operator" => "="
		    ),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function DelIncosistencia($codigo){
        $params = array(
    		"P_NRSEQUCONSOL" => $codigo,
    		"NRORG" => $this->environment->getNrorg()
    	);
    	$sql = "DELETE FROM VERIFCONSSOLOL WHERE NRSEQUCONSOL = :P_NRSEQUCONSOL AND NRORG = :NRORG";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute($params);
    }
    
    public function criaFiltroFilialPrevCons($row){
        $filter = array(
		    array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $row['CDFILIALOL'],
    		    "operator" => "="
		    ),
		     array(
    		    "columnName" => "P_PRODINI", 
    		    "value" => $row['CDPRODINI'],
    		    "operator" => "="
		    ),
		     array(
    		    "columnName" => "P_PRODFIN", 
    		    "value" => $row['PRODUTOFIN'],
    		    "operator" => "="
		    ),
		     array(
    		    "columnName" => "P_DTINICIAL", 
    		    "value" => $row['DTINI'],
    		    "operator" => "="
		    ),
		     array(
    		    "columnName" => "P_DTFINAL", 
    		    "value" => $row['DTFIM'],
    		    "operator" => "="
		    ),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroParamServico($cdfilial, $cdgrupfili){
        $filter = array(
		    array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $cdfilial,
    		    "operator" => "="
		    ),
		     array(
    		    "columnName" => "P_CDGRUPFILI", 
    		    "value" => $cdgrupfili,
    		    "operator" => "="
		    ),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroLimiSegu($cdfilial, $row){
        $filter = array(
		    array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $cdfilial,
    		    "operator" => "="
		    ),
		     array(
    		    "columnName" => "P_PRODINI", 
    		    "value" => $row['CDPRODINI'],
    		    "operator" => "="
		    ),
		     array(
    		    "columnName" => "P_PRODFIN", 
    		    "value" => $row['PRODUTOFIN'],
    		    "operator" => "="
		    ),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function dtFinalLimiteSeg($datfin, $dia){
        $dia = intval($dia);
        $date = DateTime::createFromFormat('d/m/Y', $datfin);
        $string = " +";
        $string .= $dia;
        $string .= " days";
        $date->modify($string);
        $date->modify("+1 month");
        return $date->format('d/m/Y');
    }

    public function CALCULA_PREVCONS_FILIAIS($row, $cdfilial, $dtfinallimi) {
        $procedure = new StoredProcedure($this->connection, 'CALCULA_PREVCONS_FILIAIS');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $cdfilial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_TCDFILIAL', Param::PARAM_INPUT, $row['TCFILI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPFILI', Param::PARAM_INPUT, $row['CDGRUPFILI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $dtfinallimi, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PEACRESCIMO', Param::PARAM_INPUT, $row['PEACRESCIMO'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODUTOINI', Param::PARAM_INPUT, $row['CDPRODINI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODUTOFIN', Param::PARAM_INPUT, $row['PRODUTOFIN'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $this->environment->getCdoperador(), Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTHRCALCPC', Param::PARAM_INPUT, $row['DATMOMENT'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDARREDOND', Param::PARAM_INPUT, 'N', Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_STDTFINAL', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_STDTINICIAL', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
    public function criaFiltroConfereNeceComp($codigo){
        $filter = array(
		    array(
    		    "columnName" => "P_NRSEQUCONSOL", 
    		    "value" => $codigo,
    		    "operator" => "="
		    ),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
}